io
====

Spike-based datasets are published in numerous data formats, scattered around the web and containing different data such as events, images, inertial measurement unit readings and many more. Here are some helper functions to decode your event files.

.. automodule:: tonic.io
    :members:
    